endpoint_of

Function endpoint_of 

pub(super) fn endpoint_of(operation: RegistryOperation) -> SuotarEndpoint
The Suotar endpoint that serves operation, which is also what the call log, the limiter and the dashboard key on.