study_registry_endpoints

Function study_registry_endpoints 

fn study_registry_endpoints(
    phase: CreditRegistrationPhase,
) -> impl Iterator<Item = SuotarEndpoint>
The Suotar endpoints one iteration of phase calls, in order: its crate::PhaseSpec::operations as the call log and the dashboard name them.