pub(super) fn endpoint_of(operation: RegistryOperation) -> SuotarEndpointExpand description
The Suotar endpoint that serves operation, which is also what the call log, the limiter and the
dashboard key on.
pub(super) fn endpoint_of(operation: RegistryOperation) -> SuotarEndpointThe Suotar endpoint that serves operation, which is also what the call log, the limiter and the
dashboard key on.